@@ -27,6 +27,7 @@
 //
 
 using System;
+using System.Globalization;
 
 using Mono.Cecil;
 using Mono.Cecil.Cil;
@@ -34,6 +35,7 @@ using Mono.Cecil.Cil;
 using Gendarme.Framework;
 using Gendarme.Framework.Engines;
 using Gendarme.Framework.Helpers;
+using Gendarme.Framework.Rocks;
 
 namespace Gendarme.Rules.Performance {
 
@@ -84,9 +86,9 @@ namespace Gendarme.Rules.Performance {
 
 				// look for calls to: static Type System.Type.GetType(string...)
 				MethodReference mr = (ins.Operand as MethodReference);
-				if ((mr == null) || !mr.HasParameters || (mr.Name != "GetType"))
+				if ((mr == null) || !mr.HasParameters)
 					continue;
-				if (mr.DeclaringType.FullName != "System.Type")
+				if (!mr.IsNamed ("System", "Type", "GetType"))
 					continue;
 
 				if (ins.Previous.OpCode.Code != Code.Ldstr)
@@ -100,7 +102,8 @@ namespace Gendarme.Rules.Performance {
 				if (type_name == "Mono.Runtime")
 					continue;
 
-				string msg = string.Format ("Replace call to Type.GetType(\"{0}\") into typeof({0}).", type_name);
+				string msg = String.Format (CultureInfo.InvariantCulture, 
+					"Replace call to Type.GetType(\"{0}\") into typeof({0}).", type_name);
 				Runner.Report (method, ins, Severity.Medium, Confidence.Normal, msg);
 			}
 			return Runner.CurrentRuleResult;
